@@ -4,12 +4,12 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.096 qw(:Status);
+use IO::Compress::Base::Common  2.100 qw(:Status);
 
-use Compress::Raw::Bzip2  2.096 ;
+use Compress::Raw::Bzip2  2.100 ;
 
 our ($VERSION);
-$VERSION = '2.096';
+$VERSION = '2.100';
 
 sub mkCompObject
 {
@@ -21,7 +21,7 @@ sub mkCompObject
     $WorkFactor    = 0 if ! defined $WorkFactor ;
     $Verbosity     = 0 if ! defined $Verbosity ;
 
-    my ($def, $status) = new Compress::Raw::Bzip2(1, $BlockSize100K,
+    my ($def, $status) = Compress::Raw::Bzip2->new(1, $BlockSize100K,
                                                  $WorkFactor, $Verbosity);
 
     return (undef, "Could not create Deflate object: $status", $status)
@@ -30,7 +30,7 @@ sub mkCompObject
     return bless {'Def'        => $def,
                   'Error'      => '',
                   'ErrorNo'    => 0,
-                 }  ;     
+                 }  ;
 }
 
 sub compr
@@ -44,11 +44,11 @@ sub compr
 
     if ($status != BZ_RUN_OK)
     {
-        $self->{Error} = "Deflate Error: $status"; 
+        $self->{Error} = "Deflate Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;    
+    return STATUS_OK;
 }
 
 sub flush
@@ -62,12 +62,12 @@ sub flush
 
     if ($status != BZ_RUN_OK)
     {
-        $self->{Error} = "Deflate Error: $status"; 
+        $self->{Error} = "Deflate Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;    
-    
+    return STATUS_OK;
+
 }
 
 sub close
@@ -81,12 +81,12 @@ sub close
 
     if ($status != BZ_STREAM_END)
     {
-        $self->{Error} = "Deflate Error: $status"; 
+        $self->{Error} = "Deflate Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;    
-    
+    return STATUS_OK;
+
 }
 
 
@@ -96,18 +96,18 @@ sub reset
 
     my $outer = $self->{Outer};
 
-    my ($def, $status) = new Compress::Raw::Bzip2();
+    my ($def, $status) = Compress::Raw::Bzip2->new();
     $self->{ErrorNo} = ($status == BZ_OK) ? 0 : $status ;
 
     if ($status != BZ_OK)
     {
-        $self->{Error} = "Cannot create Deflate object: $status"; 
+        $self->{Error} = "Cannot create Deflate object: $status";
         return STATUS_ERROR;
     }
 
     $self->{Def} = $def;
 
-    return STATUS_OK;    
+    return STATUS_OK;
 }
 
 sub compressedBytes
@@ -151,4 +151,3 @@ sub uncompressedBytes
 1;
 
 __END__
-
