@@ -46,7 +46,7 @@ if ($has_locale_h) {
             # number) if the platform doesn't support this category, so we
             # have an entry for all the ones that might be specified in calls
             # to us.
-            $number = $number_for_missing_category-- if $@;
+            $number = $number_for_missing_category--;
         }
         elsif (   $number !~ / ^ -? \d+ $ /x
                || $number <=  $max_bad_category_number)
@@ -92,11 +92,7 @@ sub _trylocale ($$$$) { # For use only by other functions in this file!
     # Adds the locale given by the first parameter to the list given by the
     # 3rd iff the platform supports the locale in each of the category numbers
     # given by the 2nd parameter, which is either a single category or a
-    # reference to a list of categories.  The list MUST be sorted so that
-    # CTYPE is first, COLLATE is last unless ALL is present, in which case
-    # that comes after COLLATE.  This is because locale.c detects bad locales
-    # only with CTYPE, and COLLATE on some platforms can core dump if it is a
-    # bad locale.
+    # reference to a list of categories.
     #
     # The 4th parameter is true if to accept locales that aren't apparently
     # fully compatible with Perl.
@@ -139,10 +135,34 @@ sub _trylocale ($$$$) { # For use only by other functions in this file!
     # Incompatible locales aren't warned about unless using locales.
     use locale;
 
+    # Sort the input so CTYPE is first, COLLATE comes after all but ALL.  This
+    # is because locale.c detects bad locales only with CTYPE, and COLLATE on
+    # some platforms can core dump if it is a bad locale.
+    my @sorted;
+    my $has_ctype = 0;
+    my $has_all = 0;
+    my $has_collate = 0;
     foreach my $category (@$categories) {
         die "category '$category' must instead be a number"
                                             unless $category =~ / ^ -? \d+ $ /x;
+        if ($category_name{$category} eq 'CTYPE') {
+            $has_ctype = 1;
+        }
+        elsif ($category_name{$category} eq 'ALL') {
+            $has_all = 1;
+        }
+        elsif ($category_name{$category} eq 'COLLATE') {
+            $has_collate = 1;
+        }
+        else {
+            push @sorted, $category unless grep { $_ == $category } @sorted;
+        }
+    }
+    push @sorted, $category_number{'COLLATE'} if $has_collate;
+    push @sorted, $category_number{'ALL'} if $has_all;
+    unshift @sorted, $category_number{'CTYPE'} if $has_ctype || ! $allow_incompatible;
 
+    foreach my $category (@sorted) {
         return unless setlocale($category, $locale);
         last if $badutf8 || ! $plays_well;
     }
